@@ -21,6 +21,7 @@
  ***************************************************************************/
 
 #include "jabberclient.h"
+#include "jabberbobcache.h"
 
 #include <kdebug.h>
 #include "kopetesockettimeoutwatcher.h"
@@ -790,6 +791,9 @@ JabberClient::ErrorCode JabberClient::connect ( const XMPP::Jid &jid, const QStr
 
 	d->jabberClient->setTimeZone ( timeZoneName (), timeZoneOffset () );
 
+	// Set cache for XEP-0231
+	d->jabberClient->bobManager()->setCache ( new JabberBoBCache ( d->jabberClient ) );
+
 
 	// XMPP Features from http://xmpp.org/registrar/disco-features.html
 
@@ -817,6 +821,7 @@ JabberClient::ErrorCode JabberClient::connect ( const XMPP::Jid &jid, const QStr
 	features.addFeature("jabber:x:signed");                        // XEP-0027: Current OpenPGP Usage
 	features.addFeature("urn:xmpp:delay");                         // XEP-0203: Delayed Delivery
 	features.addFeature("urn:xmpp:receipts");                      // XEP-0184: Message Delivery Receipts
+	features.addFeature("urn:xmpp:thumbs:0");                      // XEP-0264: File Transfer Thumbnails
 	d->jabberClient->setFeatures(features);
 
 	// Additional features supported by libiris, but not yet by Kopete:
@@ -1136,7 +1141,6 @@ void JabberClient::slotCSError ( int error )
 
 void JabberClient::slotCSConnected ()
 {
-#ifdef IRIS_SOCKET_ACCESS
 	Kopete::SocketTimeoutWatcher* timeoutWatcher = 0;
 
 	ByteStream *irisByteStream = d->jabberClientConnector->stream ();
@@ -1145,7 +1149,6 @@ void JabberClient::slotCSConnected ()
 
 	if ( timeoutWatcher )
 		QObject::connect( timeoutWatcher, SIGNAL(errorInt(int)), this, SLOT(slotCSError(int)) );
-#endif
 }
 
 void JabberClient::slotRosterRequestFinished ( bool success, int /*statusCode*/, const QString &/*statusString*/ )
